/**
 * Copyright (c) 2017-2019, lt 北京中世康恺科技有限公司 (www.pacsonline.cn).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 */

package com.zskk.common;

import com.jfinal.config.Constants;
import com.jfinal.config.Handlers;
import com.jfinal.config.Interceptors;
import com.jfinal.config.JFinalConfig;
import com.jfinal.config.Plugins;
import com.jfinal.config.Routes;
import com.jfinal.core.JFinal;
import com.jfinal.kit.PropKit;
import com.jfinal.plugin.activerecord.ActiveRecordPlugin;
import com.jfinal.plugin.activerecord.dialect.MysqlDialect;
import com.jfinal.plugin.druid.DruidPlugin;
import com.jfinal.template.Engine;
import com.zskk.controller.DicomController;
import com.zskk.model._MappingKit;
import com.zskk.service.ServiceFactory;

public class ZskkConfig extends JFinalConfig {
	// 本地开发模式
	private boolean isLocalDev = false;

	/**
	 * 如果生产环境配置文件存在，则优先加载该配置，否则加载开发环境配置文件
	 * 
	 * @param pro 生产环境配置文件
	 * @param dev 开发环境配置文件
	 */
	public void loadProp(String pro, String dev) {
		try {
			PropKit.use(pro);
		} catch (Exception e) {
			PropKit.use(dev);
			isLocalDev = true;
		}
	}

	public void configConstant(Constants me) {
		loadProp("config.properties", "a_little_config.txt");
		me.setDevMode(PropKit.getBoolean("devMode", false));
	}

	public void configRoute(Routes me) {
		me.add("/dcm", DicomController.class);
	}

	public static DruidPlugin createZskkDruidPlugin() {

		return new DruidPlugin(PropKit.get("jdbcUrl_zskk"), PropKit.get("user_zskk"),
				PropKit.get("password_zskk").trim());
	}

	public void configPlugin(Plugins me) {
		// 配置数据库连接池插件
//		DruidPlugin druidPluginZskk = createZskkDruidPlugin();
//		me.add(druidPluginZskk);
		// 配置ActiveRecord插件
//		ActiveRecordPlugin arpZskk = new ActiveRecordPlugin(druidPluginZskk);
//		arpZskk.setDialect(new MysqlDialect());
    	//所有映射在 MappingKit 中自动化搞定
//		_MappingKit.mapping(arpZskk);
//		me.add(arpZskk);
	}

	public void configInterceptor(Interceptors me) {

	}

	public void configHandler(Handlers me) {

	}

	/*
	 * / 运行即启动
	 */
	@Override
	public void onStart() {
		// TODO Auto-generated method stub
		super.onStart();
		ServiceFactory.init();
	}

	/*
	 * / 本地调试运行此处，线上发布注释main方法，并在maven配置文件注释jetty依赖
	 */
	public static void main(String[] args) {
		JFinal.start("src/main/webapp", 10001, "/", 5);
	}

	@Override
	public void configEngine(Engine engine) {

	}
}
